==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/installer/messages/an/base.php <==
<?php

return [
    'Downloading & Installing Modules...' => 'Baixando y instalando modulos...',
    'Next' => 'Siguient',
    'Password' => 'Clau',
    'Sign in' => 'Iniciar sesión',
    '<strong>Admin</strong> Account' => '',
    '<strong>Configuration</strong>' => '',
    '<strong>Congratulations</strong>. You\'re done.' => '',
    '<strong>Database</strong> Configuration' => '',
    '<strong>Example</strong> contents' => '',
    '<strong>Pretty URLs</strong> configuration' => '',
    '<strong>Scheduled jobs</strong>' => '',
    '<strong>System</strong> Check' => '',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '',
    'Add following the lines to the crontab:' => '',
    'Allow access for non-registered users to public content (guest access)' => '',
    'Allow friendships between members' => '',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => '',
    'Calvin Klein – Between love and madness lies obsession.' => '',
    'Check again' => '',
    'Congratulations! Everything is ok and ready to start over!' => '',
    'Create Admin Account' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'External users can register (show registration form on login)' => '',
    'Here you can decide how new, unregistered users can access HumHub.' => '',
    'Hostname' => '',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => '',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'I want to use HumHub for:' => '',
    'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => '',
    'Initializing database...' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'My club' => '',
    'My community' => '',
    'My company (Social Intranet / Project management)' => '',
    'My educational institution (school, university)' => '',
    'Name of Database' => '',
    'Name of your network' => '',
    'Newly registered users have to be activated by an admin first' => '',
    'Nike – Just buy it. :wink:' => '',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => '',
    'Ohh, something went wrong!' => '',
    'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => '',
    'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => '',
    'Port' => '',
    'Recommended <strong>Modules</strong>' => '',
    'Registered members can invite new users via email' => '',
    'Registered members can invite new users via link' => '',
    'Security <strong>Settings</strong>' => '',
    'Set up example content (recommended)' => '',
    'Skip this step, I want to set up everything manually' => '',
    'Social Network <strong>Name</strong>' => '',
    'The installation completed successfully! Have fun with your new social network.' => '',
    'The name of the database you want to run HumHub in.' => '',
    'This overview shows all system requirements of HumHub.' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => '',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => '',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => '',
    'Username' => '',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '',
    'Welcome Space' => '',
    'Yay! I\'ve just installed HumHub :sunglasses:' => '',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => '',
    'Your MySQL password.' => '',
    'Your MySQL username' => '',
    'Your first sample space to discover the platform.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/installer/messages/an/base.php <==
<?php

return [
    'Downloading & Installing Modules...' => 'Baixando y instalando modulos...',
    'Next' => 'Siguient',
    'Password' => 'Clau',
    'Sign in' => 'Iniciar sesión',
    '<strong>Admin</strong> Account' => '',
    '<strong>Apache</strong> web server detected.' => '',
    '<strong>Configuration</strong>' => '',
    '<strong>Congratulations</strong>. You\'re done.' => '',
    '<strong>Database</strong> Configuration' => '',
    '<strong>Example</strong> contents' => '',
    '<strong>Nginx</strong> web server detected.' => '',
    '<strong>Pretty URLs</strong>' => '',
    '<strong>Scheduled jobs</strong>' => '',
    '<strong>System</strong> Check' => '',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '',
    'Add following the lines to the crontab:' => '',
    'Allow access for non-registered users to public content (guest access)' => '',
    'Allow friendships between members' => '',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => '',
    'Calvin Klein – Between love and madness lies obsession.' => '',
    'Check again' => '',
    'Congratulations! Everything is ok and ready to start over!' => '',
    'Create Admin Account' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'Ensure the following rule is present in your configuration: <strong>try_files $uri $uri/ /index.php?$args;</strong>.' => '',
    'External users can register (show registration form on login)' => '',
    'For more information on this topic, please refer to our <a href="{link}" target="_blank">documentation</a>.' => '',
    'Here you can decide how new, unregistered users can access HumHub.' => '',
    'Hostname' => '',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => '',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'I want to use HumHub for:' => '',
    'In the installation folder, locate the <strong>.env.example</strong> file and copy its contents into the <strong>.env</strong> file. Next, find the <strong>Pretty URLs</strong> block and uncomment it by removing the <strong>#</strong> symbol.' => '',
    'Initializing database...' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'Make sure that the following file is writable: thi' => '',
    'My club' => '',
    'My community' => '',
    'My company (Social Intranet / Project management)' => '',
    'My educational institution (school, university)' => '',
    'Name of Database' => '',
    'Name of your network' => '',
    'Newly registered users have to be activated by an admin first' => '',
    'Nike – Just buy it. :wink:' => '',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => '',
    'Ohh, something went wrong!' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Port' => '',
    'Pretty URLs may not work correctly.' => '',
    'Pretty URLs should work correctly.' => '',
    'Recommended <strong>Modules</strong>' => '',
    'Registered members can invite new users via email' => '',
    'Registered members can invite new users via link' => '',
    'Security <strong>Settings</strong>' => '',
    'Set up example content (recommended)' => '',
    'Skip this step, I want to set up everything manually' => '',
    'Social Network <strong>Name</strong>' => '',
    'The <strong>.htaccess</strong> file is in place.' => '',
    'The <strong>.htaccess</strong> file is not in place. In the installation folder, locate the <strong>.htaccess.dist</strong> file and rename it to <strong>.htaccess</strong>.' => '',
    'The <strong>mod_rewrite</strong> module is active.' => '',
    'The <strong>mod_rewrite</strong> module is not enabled.' => '',
    'The installation completed successfully! Have fun with your new social network.' => '',
    'The name of the database you want to run HumHub in.' => '',
    'This overview shows all system requirements of HumHub.' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => '',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => '',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => '',
    'Unable to automatically detect your web server type. Please ensure URL rewriting is configured.' => '',
    'Username' => '',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '',
    'Welcome Space' => '',
    'Yay! I\'ve just installed HumHub :sunglasses:' => '',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => '',
    'Your MySQL password.' => '',
    'Your MySQL username' => '',
    'Your first sample space to discover the platform.' => '',
];
